@@ -1253,7 +1253,7 @@ parsebackq: {
 	union node *n;
 	char *str;
 	size_t savelen;
-	int saveprompt;
+	int saveprompt = 0;
 
 	str = NULL;
 	savelen = out - (char *)stackblock();
@@ -1414,7 +1414,7 @@ STATIC int
 noexpand(char *text)
 {
 	char *p;
-	char c;
+	signed char c;
 
 	p = text;
 	while ((c = *p++) != '\0') {
